.. toctree::
   :caption: Contents
   :hidden:

   Introduction <self>
   Examples <examples>
   supercell
   API Reference <api>
   Change Log <changelog>
   Developer Note <developer_note>
   genindex

.. mdinclude:: ../README.md
